Important changes to repositories hosted on mbed.com
Mbed hosted mercurial repositories are deprecated and are due to be permanently deleted in July 2026.
To keep a copy of this software download the repository Zip archive or clone locally using Mercurial.
It is also possible to export all your personal repositories from the account settings page.
Fork of NokiaLCD by
Revision 3:51cb48ebad3e, committed 2014-10-24
- Comitter:
- Capper
- Date:
- Fri Oct 24 15:34:27 2014 +0000
- Parent:
- 2:2d1b23692cbb
- Commit message:
- Changed orientation and contrast for this project
Changed in this revision
| NokiaLCD.cpp | Show annotated file Show diff for this revision Revisions of this file |
--- a/NokiaLCD.cpp Fri Nov 19 22:12:28 2010 +0000
+++ b/NokiaLCD.cpp Fri Oct 24 15:34:27 2014 +0000
@@ -54,7 +54,7 @@
data(0x0F);
command(0xA7); // invert display
command(0x81); // Voltage control
- data(39); // contrast setting: 0..63
+ data(0x23); // contrast setting: 0..63 was39
data(3); // resistance ratio
wait_ms(1);
command(0xBC);
@@ -92,9 +92,9 @@
command(0x3A); // column mode
data(0x05);
command(0x36); // madctl
- data(0x60); // vertical RAM, flip x
+ data(0x00); // vertical RAM, flip x was 60 RSC
command(0x25); // setcon
- data(0x30);// contrast 0x30
+ data(0x40);// contrast was 0x30 RSC
wait_ms(2);
command(0x29);//DISPON
command(0x03);//BSTRON
